<?php
/**
 * Created by PhpStorm.
 * User: tiger
 * Date: 2017/07/26
 * Time: 20:34
 */

/**
 * Page to select room Type to add new task.
 */
function room_admin_add_page() {
    $items = array();
    foreach (room_types() as $type_key => $room_type) {
        $items[] = l(entity_label('room_type', $room_type), 'room/add/' . $type_key);
    }
    return array('list' => array('#theme' => 'item_list',
                                '#items' => $items,
                                '#title' => t('Select room type to create.'))
                );
}

/**
 * Task view callback.
 */
function room_view($room, $view_mode="full") {

    drupal_set_title(entity_label('room', $room));

    return entity_view('room', array(entity_id('room', $room) => $room), $view_mode);
}

/**
 * Add new room page callback.
 */
function room_add($type) {
    $room_type = room_types($type);

    $room = entity_create('room', array('room_type_sys' => $type));
    drupal_set_title(t('Create @name', array('@name' => entity_label('room_type', $room_type ))));

    $output = drupal_get_form('room_form', $room);

    return $output;
}

/**
 * Room Form.
 */
function room_form($form, &$form_state, $room) {
    $form_state['room'] = $room;

    $form['room_label'] = array(
        '#type' => 'textfield',
        '#maxlength' => 32,
        '#required' => TRUE,
        '#title' => t('Room Name'),
        '#default_value' => isset( $room->room_label ) ? $room->room_label : "",
    );

    $form['room_type_sys'] = array(
        '#type' => 'value',
        '#value' => $room->room_type_sys,
    );

    $form['room_area'] = array(
        '#type' => 'textfield',
        '#title' => t('Room Area'),
        '#maxlength' => 32,
        '#default_value' => isset( $room->room_area ) ? $room->room_area : "",
    );

    field_attach_form('room', $room, $form, $form_state);

    $submit = array();
    if (!empty($form['#submit'])) {
        $submit += $form['#submit'];
    }

    $form['actions'] = array(
        '#weight' => 100,
    );

    $form['actions']['submit'] = array(
        '#type' => 'submit',
        '#value' => t('Save room'),
        '#submit' => $submit + array('room_form_submit'),
    );

    // Show Delete button if we edit task.
    $rid = entity_id('room' ,$room);
    if (!empty($rid) ) {
        $form['actions']['delete'] = array(
            '#type' => 'submit',
            '#value' => t('Delete'),
            '#submit' => array('room_form_submit_delete'),
        );
    }

//    $form['#validate'][] = 'room_form_validate';

    return $form;
}


/**
 * Task submit handler.
 */
function room_form_submit($form, &$form_state) {
    $room = $form_state['room'];

    entity_form_submit_build_entity('room', $room, $form, $form_state);
    room_save($room);

    $room_uri = entity_uri('room', $room);
    $form_state['redirect'] = $room_uri['path'];

    drupal_set_message(t('Task %title saved.', array('%title' => entity_label('room', $room))));
}

